@@ -5,7 +5,11 @@ import os
 import signal
 import sys
 
-from mopidy.internal.gi import Gst  # noqa: Import to initialize
+import pykka.debug
+
+from mopidy import commands, config as config_lib, ext
+from mopidy.internal import encoding, log, path, process, versioning
+from mopidy.internal.gi import Gst  # noqa: F401
 
 try:
     # Make GObject's mainloop the event loop for python-dbus
@@ -15,10 +19,6 @@ try:
 except ImportError:
     pass
 
-import pykka.debug
-
-from mopidy import commands, config as config_lib, ext
-from mopidy.internal import encoding, log, path, process, versioning
 
 logger = logging.getLogger(__name__)
 
